This repository contains pyhton code for working with the source data ([SPP-CLS_AnnotationTables_Data](https://cls-gitlab.phil.uni-wuerzburg.de/spp-cls-data-exchange/spp-cls_annotationtables_data))

## Installation

Setup an virtual environment, if necessary:

```sh
python3 -m venv env
source env/bin/activate
```

Install dependencies:

```sh
pip install -r requirements.txt
python -m spacy download de_core_news_lg
```

**cls.py**

**tokenise.py**

TODO: fix character offset to be byte instead

**check.py** 
